database

package
v0.0.0-...-576298e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 19, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Database

type Database interface {
	Tables() table.Names
	Table(table.Name) (table.Table, bool)
	CreateTable(table.Name, ...column.Column) (table.Table, error)
}

Database is an interface that manages a set of Tables and other data management structures

type Query

type Query func(Database) error

Query is a function that can perform Database queries or mutations

type Transactor

type Transactor func(Query) (Transactor, error)

Transactor provides access to a Database's internal state

Jump to