prefix

package
v0.0.0-...-576298e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 19, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Prefix

type Prefix uint32

Prefix is used to partition Database elements within the same underlying data structure

var Start Prefix

Start is the Prefix zero-value

func (Prefix) Bytes

func (p Prefix) Bytes() []byte

Bytes returns the underlying byte slice of the Prefix

func (Prefix) Next

func (p Prefix) Next() Prefix

Next returns the next Prefix in sequence

func (Prefix) Prefix

func (p Prefix) Prefix() Prefix

Prefix makes Prefix a Prefixed instance

func (Prefix) WithKey

func (p Prefix) WithKey(k value.Key) value.Key

WithKey combines this Prefix with a provided Key into a byte array

func (Prefix) WithKeys

func (p Prefix) WithKeys(keys ...value.Key) value.Key

WithKeys combines this Prefix with the provided Keys into a byte array

type Prefixed

type Prefixed interface {
	Prefix() Prefix
}

Prefixed is a type that is associated with a Prefix

Jump to