table

package
v0.0.0-...-576298e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 19, 2023 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Name

type Name string

Name identifies a Table

type Names

type Names []Name

Names are a set of Name

type Table

type Table interface {
	Name() Name
	Columns() column.Columns

	Indexes() index.Names
	CreateIndex(index.Type, index.Name, ...column.Name) error

	Insert(value.Key, relation.Row) error
	Update(value.Key, relation.Row) (relation.Row, error)
	Delete(value.Key) (relation.Row, bool)
	Truncate()

	Select(value.Key) (relation.Row, bool)
}

Table is an interface that associates a Key with a Row and provides additional capabilities around this association

Jump to