transaction

package
v0.0.0-...-576298e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 19, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type For

type For interface {
	Mutate
	Query
}

For exposes actions that are bound to a specific Prefixed

type Iterable

type Iterable interface {
	All() Iterator
	From(value.Key) Iterator
}

Iterable can be used to generate an Iterator

type Iterator

type Iterator func() (value.Key, any, Iterator, bool)

Iterator is stateless iteration interface

type Mutate

type Mutate interface {
	Insert(value.Key, any) (any, bool)
	Delete(value.Key) (any, bool)
	Drop() bool
}

Mutate allows changed to data of a Prefixed For

type Query

type Query interface {
	Get(value.Key) (any, bool)
	Ascending() Iterable
	Descending() Iterable
}

Query allows retrieval of data from a Prefixed For

type Txn

type Txn interface {
	For(prefix.Prefixed) For
}

Txn manages the types of actions that can be performed at the most basic level of the storage system

type WriterFunc

type WriterFunc func(Txn) error

WriterFunc is provided in order to sequence transactional writes

Directories

Path Synopsis

Jump to