package
Version:
v0.0.0-...-576298e
Opens a new window with list of versions in this module.
Published: Jun 19, 2023
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Prefix is used to partition Database elements within the same
underlying data structure
Start is the Prefix zero-value
Bytes returns the underlying byte slice of the Prefix
Next returns the next Prefix in sequence
Prefix makes Prefix a Prefixed instance
WithKey combines this Prefix with a provided Key into a byte array
WithKeys combines this Prefix with the provided Keys into a byte array
type Prefixed interface {
Prefix() Prefix
}
Prefixed is a type that is associated with a Prefix
Source Files
¶
Click to show internal directories.
Click to hide internal directories.