Documentation
¶
Index ¶
Constants ¶
const (
ErrColumnNotFound = "column not found in table: %s"
)
Error messages
Variables ¶
var StarSelector = Selector(func(r Row) Relation { return Relation(r) })
StarSelector is used to retrieve the entire Row as a Relation
Functions ¶
Types ¶
type Selector ¶
Selector is a function that takes a Row and returns a Relation
func MakeNamedSelector ¶
MakeNamedSelector takes a Columns and a set of Name and returns a Selector that can be used to convert a Row to the desired Relation
func MakeOffsetSelector ¶
MakeOffsetSelector returns a Selector based on the specified Offsets
Click to show internal directories.
Click to hide internal directories.