Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Mutate ¶
type Mutate interface {
Insert(value.Key, any) (any, bool)
Delete(value.Key) (any, bool)
Drop() bool
}
Mutate allows changed to data of a Prefixed For
type Txn ¶
Txn manages the types of actions that can be performed at the most basic level of the storage system
type WriterFunc ¶
WriterFunc is provided in order to sequence transactional writes
Click to show internal directories.
Click to hide internal directories.