Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ForEach ¶
func ForEach(iter transaction.Iterator, fn Reporter) error
ForEach iterates over a transaction.Iterator and calls a Reporter for each pair. If that Reporter returns an error, the iteration is canceled and the error is returned
func While ¶
func While(iter transaction.Iterator, fn Predicate) transaction.Iterator
While iterates over a transaction.Iterator and checks its pairs against the provided Predicate. The iteration is canceled the first time the Predicate returns false
Types ¶
Click to show internal directories.
Click to hide internal directories.