Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Bool ¶
type Bool bool
Bool is a Value that represents a stored boolean
func (Bool) Compare ¶
func (l Bool) Compare(r Value) Comparison
Compare returns a Comparison between this Bool and another Value
type Comparison ¶
type Comparison int
Comparison represents the result of an equality comparison
const ( LessThan Comparison = iota - 1 EqualTo GreaterThan Incomparable )
Comparison results
type Float ¶
type Float float64
Float is a Value that represents a stored floating point number
func (Float) Compare ¶
func (l Float) Compare(r Value) Comparison
Compare returns a Comparison between this Float and another Value
type Integer ¶
type Integer int64
Integer is a Value that represents a stored integer
func (Integer) Compare ¶
func (l Integer) Compare(r Value) Comparison
Compare returns a Comparison between this Integer and another Value
type Key ¶
type Key []byte
Key is a Value that represents a database key
func (Key) Compare ¶
func (l Key) Compare(r Value) Comparison
Compare returns a Comparison between this Key and another Value
type String ¶
type String string
String is a Value that represents a stored string
func (String) Compare ¶
func (l String) Compare(r Value) Comparison
Compare returns a Comparison between this String and another Value
type Value ¶
type Value interface {
Compare(Value) Comparison
Bytes() []byte
}
Value is a placeholder for what will eventually be a generic